'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _ColorPicker = require('./ColorPicker');

var _ColorPicker2 = _interopRequireDefault(_ColorPicker);

var _cfStyleContainer = require('cf-style-container');

var _cfComponentInput = require('cf-component-input');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const CoverDiv = (0, _cfStyleContainer.createComponent)(() => ({
  position: 'fixed',
  top: '0px',
  right: '0px',
  bottom: '0px',
  left: '0px'
}), 'div', ['onClick']);
CoverDiv.setDisplayName('CoverDiv');

const PopoverDiv = (0, _cfStyleContainer.createComponent)(() => ({
  position: 'absolute',
  zIndex: '2'
}), 'div');
PopoverDiv.setDisplayName('PopoverDiv');

const FakeInputDiv = (0, _cfStyleContainer.createComponent)(({ theme }) => {
  return Object.assign({}, (0, _cfComponentInput.InputTheme)(theme), {
    padding: '.6em .9em'
  });
}, 'div', ['onClick']);
FakeInputDiv.setDisplayName('FakeInputDiv');

const ColorDisplayDiv = (0, _cfStyleContainer.createComponent)(({ theme, color, defaultColor }) => {
  return {
    background: color || defaultColor,
    height: '100%',
    width: '100%',
    borderWidth: '1px',
    borderStyle: 'solid',
    borderColor: theme.color.hail
  };
}, 'div');
ColorDisplayDiv.setDisplayName('ColorDisplayDiv');

class ColorPickerInput extends _react2.default.Component {
  constructor(props) {
    super(props);
    this.state = {
      displayColorPicker: false
    };

    this.handleChange = this.handleChange.bind(this);
    this.handleClose = this.handleClose.bind(this);
    this.handleClick = this.handleClick.bind(this);
  }

  handleClick(e) {
    e.preventDefault();
    this.setState({ displayColorPicker: !this.state.displayColorPicker });
  }

  handleClose() {
    this.setState({ displayColorPicker: false });
  }

  handleChange(color) {
    this.props.onChange({ value: color.hex });
  }

  render() {
    const { defaultEmptyValue, value } = this.props;
    return _react2.default.createElement(
      'div',
      null,
      _react2.default.createElement(
        FakeInputDiv,
        { onClick: this.handleClick },
        _react2.default.createElement(ColorDisplayDiv, { color: value, defaultColor: defaultEmptyValue })
      ),
      this.state.displayColorPicker ? _react2.default.createElement(
        PopoverDiv,
        null,
        _react2.default.createElement(CoverDiv, { onClick: this.handleClose }),
        _react2.default.createElement(_ColorPicker2.default, { color: value, onChange: this.handleChange })
      ) : null
    );
  }
}

ColorPickerInput.propTypes = {
  defaultEmptyValue: _propTypes2.default.string,
  onChange: _propTypes2.default.func,
  value: _propTypes2.default.string
};

exports.default = ColorPickerInput;